@@ -14,7 +14,7 @@ use Mojo::Template::Exception;
 
 __PACKAGE__->attr('code',         default => '');
 __PACKAGE__->attr('comment_mark', default => '#');
-__PACKAGE__->attr('compiled');
+__PACKAGE__->attr([qw/compiled namespace/]);
 __PACKAGE__->attr('encoding',        default => 'utf8');
 __PACKAGE__->attr('expression_mark', default => '=');
 __PACKAGE__->attr('line_start',      default => '%');
@@ -62,8 +62,9 @@ sub build {
     }
 
     # Wrap
+    my $namespace = $self->namespace || ref $self;
     $lines[0] ||= '';
-    $lines[0] = q/sub { my $_MOJO = '';/ . $lines[0];
+    $lines[0] = qq/package $namespace; sub { my \$_MOJO = '';/ . $lines[0];
     $lines[-1] .= q/return $_MOJO; };/;
 
     $self->code(join "\n", @lines);
@@ -90,8 +91,16 @@ sub compile {
 sub interpret {
     my $self = shift;
 
-    # Shortcut
+    # Compile
+    unless ($self->compiled) {
+        my $e = $self->compile;
+
+        # Exception
+        return $e if ref $e;
+    }
     my $compiled = $self->compiled;
+
+    # Shortcut
     return unless $compiled;
 
     # Catch errors
@@ -305,7 +314,7 @@ sub _write_file {
     # Write to file
     $file->syswrite($output) or croak "Can't write to file '$path': $!";
 
-    return 0;
+    return;
 }
 
 1;
@@ -336,7 +345,7 @@ Mojo::Template - Perlish Templates!
     %= 5 * 5
     % my ($number, $text) = @_;
     test 123
-    foo <% my $i = $number + 2 %>
+    foo <% my $i = $number + 2; %>
     % for (1 .. 23) {
     * some text <%= $i++ %>
     % }
@@ -451,6 +460,11 @@ L<Mojo::Template> implements the following attributes.
     my $line_start = $mt->line_start;
     $mt            = $mt->line_start('%');
 
+=head2 C<namespace>
+
+    my $namespace = $mt->namespace;
+    $mt           = $mt->namespace('main');
+
 =head2 C<template>
 
     my $template = $mt->template;
