@@ -7,21 +7,21 @@ use warnings;
 
 use base 'MojoX::Routes';
 
-use Mojo::ByteStream;
+use Mojo::ByteStream 'b';
 use Mojo::Loader;
 use Mojo::Loader::Exception;
 
 __PACKAGE__->attr('disallow',
-    default => sub { [qw/new app attr render req res stash/] });
+    default =>
+      sub { [qw/new app attr render render_partial req res stash url_for/] });
 __PACKAGE__->attr('namespace');
 
 # Hey. What kind of party is this? There's no booze and only one hooker.
 sub dispatch {
-    my ($self, $c, $match) = @_;
+    my ($self, $c) = @_;
 
     # Match
-    $match = $self->match($match || $c->tx->req->url->path->to_string)
-      unless ref $match;
+    my $match = $self->match($c->req->method, $c->req->url->path->to_string);
     $c->match($match);
 
     # No match
@@ -30,8 +30,7 @@ sub dispatch {
     # Initialize stash with captures
     my %captures = %{$match->captures};
     foreach my $key (keys %captures) {
-        $captures{$key} =
-          Mojo::ByteStream->new($captures{$key})->url_unescape->to_string;
+        $captures{$key} = b($captures{$key})->url_unescape->to_string;
     }
     $c->stash({%captures});
 
@@ -43,11 +42,98 @@ sub dispatch {
     $self->render($c);
 
     # All seems ok
-    return 0;
+    return;
+}
+
+sub dispatch_callback {
+    my ($self, $c) = @_;
+
+    # Debug
+    $c->app->log->debug(qq/Dispatching callback./);
+
+    # Catch errors
+    local $SIG{__DIE__} = sub { die Mojo::Loader::Exception->new(shift) };
+
+    # Dispatch
+    my $continue;
+    my $cb = $c->match->captures->{callback};
+    eval { $continue = $cb->($c) };
+
+    # Success!
+    return 1 if $continue;
+
+    # Callback error
+    if ($@) {
+        $c->app->log->error($@);
+        return $@;
+    }
+
+    return;
+}
+
+sub dispatch_controller {
+    my ($self, $c) = @_;
+
+    # Method
+    my $method = $self->generate_method($c);
+    return unless $method;
+
+    # Class
+    my $class = $self->generate_class($c);
+    return unless $class;
+
+    # Debug
+    $c->app->log->debug(qq/Dispatching "${class}::$method"./);
+
+    # Load class
+    $self->{_loaded} ||= {};
+    unless ($self->{_loaded}->{$class}) {
+
+        # Load
+        if (my $e = Mojo::Loader->load($class)) {
+
+            # Doesn't exist
+            return unless ref $e;
+
+            # Error
+            $c->app->log->error($e);
+            return $e;
+        }
+
+        # Loaded
+        $self->{_loaded}->{$class}++;
+    }
+
+    # Not a conroller
+    unless ($class->isa('MojoX::Dispatcher::Routes::Controller')) {
+        $c->app->log->debug(qq/"$class" is not a controller./);
+        return;
+    }
+
+    # Catch errors
+    local $SIG{__DIE__} = sub { die Mojo::Loader::Exception->new(shift) };
+
+    # Dispatch
+    my $continue;
+    eval { $continue = $class->new(ctx => $c)->$method($c) };
+
+    # Success!
+    return 1 if $continue;
+
+    # Controller error
+    if ($@) {
+        $c->app->log->error($@);
+        return $@;
+    }
+
+    return;
 }
 
 sub generate_class {
-    my ($self, $c, $field) = @_;
+    my ($self, $c) = @_;
+
+    # Field
+    my $field = $c->match->captures;
 
     # Class
     my $class = $field->{class};
@@ -60,7 +146,7 @@ sub generate_class {
             next unless $part;
 
             # Camelize
-            push @class, Mojo::ByteStream->new($part)->camelize;
+            push @class, b($part)->camelize;
         }
         $class = join '::', @class;
     }
@@ -70,13 +156,16 @@ sub generate_class {
     $class = length $class ? "${namespace}::$class" : $namespace;
 
     # Invalid
-    return undef unless $class =~ /^[a-zA-Z0-9_:]+$/;
+    return unless $class =~ /^[a-zA-Z0-9_:]+$/;
 
     return $class;
 }
 
 sub generate_method {
-    my ($self, $c, $field) = @_;
+    my ($self, $c) = @_;
+
+    # Field
+    my $field = $c->match->captures;
 
     # Prepare disallow
     unless ($self->{_disallow}) {
@@ -87,12 +176,15 @@ sub generate_method {
     my $method = $field->{method};
     $method ||= $field->{action};
 
+    # Shortcut
+    return unless $method;
+
     # Shortcut for disallowed methods
-    return undef if $self->{_disallow}->{$method};
-    return undef if index($method, '_') == 0;
+    return if $self->{_disallow}->{$method};
+    return if index($method, '_') == 0;
 
     # Invalid
-    return undef unless $method =~ /^[a-zA-Z0-9_:]+$/;
+    return unless $method =~ /^[a-zA-Z0-9_:]+$/;
 
     return $method;
 }
@@ -101,7 +193,7 @@ sub render {
     my ($self, $c) = @_;
 
     # Render
-    $c->render unless $c->stash->{rendered} || $c->res->code;
+    $c->render unless $c->stash->{rendered};
 }
 
 sub walk_stack {
@@ -113,63 +205,24 @@ sub walk_stack {
         # Don't cache errors
         local $@;
 
-        # Method
-        my $method = $self->generate_method($c, $field);
-        next unless $method;
-
-        # Class
-        my $class = $self->generate_class($c, $field);
-        next unless $class;
-
-        # Debug
-        $c->app->log->debug(qq/Dispatching "${class}::$method"./);
-
         # Captures
         $c->match->captures($field);
 
-        # Load class
-        $self->{_loaded} ||= {};
-        my $e = 0;
-        unless ($self->{_loaded}->{$class}) {
-            $e = Mojo::Loader->new->load($class);
-            $self->{_loaded}->{$class}++ unless $e;
-        }
-
-        # Load error
-        if ($e && $e->loaded) {
-            $c->app->log->debug($e);
-            return $e;
-        }
-
-        # Check class
-        eval {
-            die
-              unless $class->isa('MojoX::Dispatcher::Routes::Controller');
-        };
-
-        # Not a conroller
-        if ($@) {
-            $c->app->log->debug(qq/"$class" is not a controller./);
-            return 1;
-        }
-
         # Dispatch
-        my $done;
-        eval { $done = $class->new(ctx => $c)->$method($c) };
+        my $e =
+            $field->{callback}
+          ? $self->dispatch_callback($c)
+          : $self->dispatch_controller($c);
 
-        # Controller error
-        if ($@) {
-            my $e = Mojo::Loader::Exception->new($class, $@);
-            $c->app->log->debug($e);
-            return $e;
-        }
+        # Exception
+        return $e if ref $e;
 
         # Break the chain
-        last unless $done;
+        return 1 unless $e;
     }
 
     # Done
-    return 0;
+    return;
 }
 
 1;
@@ -213,25 +266,25 @@ implements the follwing the ones.
 
 =head2 C<dispatch>
 
-    my $exception = $dispatcher->dispatch(
+    my $e = $dispatcher->dispatch(
         MojoX::Dispatcher::Routes::Context->new
     );
-    my $exception = $dispatcher->dispatch(
-        MojoX::Dispatcher::Routes::Context->new,
-        MojoX::Routes::Match->new
-    );
-    my $exception = $dispatcher->dispatch(
-        MojoX::Dispatcher::Routes::Context->new,
-        '/foo/bar/baz'
-    );
+
+=head2 C<dispatch_callback>
+
+    my $e = $dispatcher->dispatch_callback($c);
+
+=head2 C<dispatch_controller>
+
+    my $e = $dispatcher->dispatch_controller($c);
 
 =head2 C<generate_class>
 
-    my $class = $dispatcher->generate_class($c, $field);
+    my $class = $dispatcher->generate_class($c);
 
 =head2 C<generate_method>
 
-    my $method = $dispatcher->genrate_method($c, $field);
+    my $method = $dispatcher->genrate_method($c);
 
 =head2 C<render>
 
@@ -239,6 +292,6 @@ implements the follwing the ones.
 
 =head2 C<walk_stack>
 
-    my $exception = $dispatcher->walk_stack($c);
+    my $e = $dispatcher->walk_stack($c);
 
 =cut
