@@ -24,7 +24,12 @@ __PACKAGE__->attr('static',
     default => sub { MojoX::Dispatcher::Static->new });
 __PACKAGE__->attr('types', default => sub { MojoX::Types->new });
 
-# The usual constructor stuff
+# It's just like the story of the grasshopper and the octopus.
+# All year long, the grasshopper kept burying acorns for the winter,
+# while the octopus mooched off his girlfriend and watched TV.
+# But then the winter came, and the grasshopper died,
+# and the octopus ate all his acorns.
+# And also he got a racecar. Is any of this getting through to you?
 sub new {
     my $self = shift->SUPER::new(@_);
 
@@ -43,27 +48,38 @@ sub new {
     my $mode = $self->mode;
 
     # Log file
-    $self->log->path($self->home->rel_file("log/$mode.log"));
+    $self->log->path($self->home->rel_file("log/$mode.log"))
+      if -w $self->home->rel_file('log');
 
     # Run mode
     $mode = $mode . '_mode';
-    $self->$mode if $self->can($mode);
+    eval { $self->$mode } if $self->can($mode);
+    $self->log->error(qq/Mode "$mode" failed: $@/) if $@;
 
     # Startup
-    $self->startup(@_);
+    eval { $self->startup(@_) };
+    $self->log->error("Startup failed: $@") if $@;
 
     # Load context class
-    Mojo::Loader->new->load($self->ctx_class);
+    my $class = $self->ctx_class;
+    if (my $e = Mojo::Loader->new->load($class)) {
+        $self->log->error(
+            ref $e
+            ? qq/Couldn't load context class "$class": $e/
+            : qq/Context class "$class" doesn't exist./
+        );
+    }
 
     return $self;
 }
 
+# The context builder
 sub build_ctx {
     my $self = shift;
     return $self->ctx_class->new(app => $self, tx => shift);
 }
 
-# You could just overload this method
+# The default dispatchers with exception handling
 sub dispatch {
     my ($self, $c) = @_;
 
@@ -102,18 +118,20 @@ sub handler {
     # Start timer
     my $start = [Time::HiRes::gettimeofday()];
 
-    # Build context and dispatch
-    $self->dispatch($self->build_ctx($tx));
+    # Build context and process
+    eval { $self->process($self->build_ctx($tx)) };
+    $self->log->error("Processing request failed: $@") if $@;
 
     # End timer
     my $elapsed = sprintf '%f',
       Time::HiRes::tv_interval($start, [Time::HiRes::gettimeofday()]);
     my $rps = $elapsed == 0 ? '??' : sprintf '%.3f', 1 / $elapsed;
     $self->log->debug("Request took $elapsed seconds ($rps/s).");
-
-    return $tx;
 }
 
+# This will run for each request
+sub process { shift->dispatch(@_) }
+
 # This will run once at startup
 sub startup { }
 
@@ -133,15 +151,15 @@ Mojolicious - Web Framework
 
         my $r = $self->routes;
 
-        $r->route('/(controller)/(action)')
+        $r->route('/:controller/:action')
           ->to(controller => 'foo', action => 'bar');
     }
 
 =head1 DESCRIPTION
 
-L<Mojolicous> is a web framework built upon L<Mojo>.
+L<Mojolicous> is a MVC web framework built upon L<Mojo>.
 
-See L<Mojo::Manual::Mojolicious> for user friendly documentation.
+For userfriendly documentation see L<Mojo::Manual::Mojolicious>.
 
 =head1 ATTRIBUTES
 
@@ -153,15 +171,6 @@ following new ones.
     my $mode = $mojo->mode;
     $mojo    = $mojo->mode('production');
 
-Returns the current mode if called without arguments.
-Returns the invocant if called with arguments.
-Defaults to C<$ENV{MOJO_MODE}> or C<development>.
-
-    my $mode = $mojo->mode;
-    if ($mode =~ m/^dev/) {
-        do_debug_output();
-    }
-
 =head2 C<renderer>
 
     my $renderer = $mojo->renderer;
@@ -191,11 +200,6 @@ new ones.
 
     my $mojo = Mojolicious->new;
 
-Returns a new L<Mojolicious> object.
-This method will call the method C<${mode}_mode> if it exists.
-(C<$mode> being the value of the attribute C<mode>).
-For example in production mode, C<production_mode> will be called.
-
 =head2 C<build_ctx>
 
     my $c = $mojo->build_ctx($tx);
@@ -208,6 +212,10 @@ For example in production mode, C<production_mode> will be called.
 
     $tx = $mojo->handler($tx);
 
+=head2 C<process>
+
+    $mojo->process($c);
+
 =head2 C<startup>
 
     $mojo->startup($tx);
